@@ -2,12 +2,10 @@
 
 #include <memory>
 
-namespace precice {
-namespace acceleration {
+namespace precice::acceleration {
 class Acceleration;
 class AccelerationConfiguration;
 
 using PtrAcceleration              = std::shared_ptr<Acceleration>;
 using PtrAccelerationConfiguration = std::shared_ptr<AccelerationConfiguration>;
-} // namespace acceleration
-} // namespace precice
+} // namespace precice::acceleration
