@@ -5,9 +5,7 @@
 #include "logging/LogMacros.hpp"
 #include "utils/assertion.hpp"
 
-namespace precice {
-namespace acceleration {
-namespace impl {
+namespace precice::acceleration::impl {
 
 ConstantPreconditioner::ConstantPreconditioner(std::vector<double> factors)
     : Preconditioner(-1),
@@ -41,9 +39,7 @@ void ConstantPreconditioner::_update_(bool                   timeWindowComplete,
                                       const Eigen::VectorXd &res)
 {
 
-  //nothing to do here
+  // nothing to do here
 }
 
-} // namespace impl
-} // namespace acceleration
-} // namespace precice
+} // namespace precice::acceleration::impl
