@@ -2,16 +2,17 @@
 
 #include "testing/Testing.hpp"
 
-#include <precice/SolverInterface.hpp>
+#include <precice/precice.hpp>
 #include "helpers.hpp"
 
 BOOST_AUTO_TEST_SUITE(Integration)
 BOOST_AUTO_TEST_SUITE(Serial)
 BOOST_AUTO_TEST_SUITE(MappingVolume)
+PRECICE_TEST_SETUP("SolverOne"_on(1_rank), "SolverTwo"_on(1_rank))
 BOOST_AUTO_TEST_CASE(OneTetraRead)
 {
-  PRECICE_TEST("SolverOne"_on(1_rank), "SolverTwo"_on(1_rank));
-  testMappingVolumeOneTetra(context.config(), context);
+  PRECICE_TEST();
+  testMappingVolumeOneTetra(context.config(), context, true);
 }
 
 BOOST_AUTO_TEST_SUITE_END() // Integration
